==> order-center-domain-2.0.9-CLOUD-TEST-20220409.043044-69-sources.jar: com/tydic/dyc/oc/model/insporder/IUocInspOrderModel.java <==
package com.tydic.dyc.oc.model.insporder;

import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderItemQryBo;
import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderQryBo;
import com.tydic.dyc.oc.model.insporder.sub.UocInspOrderItem;
import com.tydic.dyc.oc.model.saleorder.sub.UocSaleOrderItem;

import java.util.List;

/**
 * 标题:IUocInspOrderModel
 * 说明:验收单
 * 时间:2022/2/25 11:34
 * 作者:罗有
 */

public interface IUocInspOrderModel {
    /**
     * 创建验收单
     */
    void createInspOrder(UocInspOrderDo uocInspOrderDo);

    /**
     * 查询验收单主体
     *
     * @param uocInspOrderQryBo
     * @return
     */
    UocInspOrderDo getInspOrderMain(UocInspOrderQryBo uocInspOrderQryBo);

    /**
     * 查询验收单明细列表
     *
     * @param uocInspOrderItemQryBo
     * @return
     */
    UocInspOrderDo getListInspOrderItem(UocInspOrderItemQryBo uocInspOrderItemQryBo);

    /**
     * 查询验收单列表
     *
     * @param uocInspOrderQryBo
     * @return
     */
    List<UocInspOrderDo> getListInspOrder(UocInspOrderQryBo uocInspOrderQryBo);
    /**
     * 获取验收单编号
     */
    UocInspOrderDo getInspOrderNo(UocInspOrderDo uocInspOrderDo);

    /**
     * 查询验收总金额总数量
     * @author wenle
     * @date 2022-04-02 10:06:02
     * @param uocInspOrderQryBo 入参
     * @return com.tydic.dyc.oc.model.insporder.UocInspOrderDo
     */
    UocInspOrderDo qryTotalFeeAndCount(UocInspOrderQryBo uocInspOrderQryBo);


    /***
     *修改明细在途数量
     * @param uocSaleOrderItem
     */
    void modifySaleOrderItemReturningCount(UocInspOrderItem uocSaleOrderItem);
}

==> order-center-domain-3.1.0-CLOUD-TEST-20230731.024047-76-sources.jar: com/tydic/dyc/oc/model/insporder/IUocInspOrderModel.java <==
package com.tydic.dyc.oc.model.insporder;

import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderItemQryBo;
import com.tydic.dyc.oc.model.insporder.qrybo.UocInspOrderQryBo;
import com.tydic.dyc.oc.model.insporder.sub.UocInspOrderItem;
import com.tydic.dyc.oc.model.saleorder.sub.UocSaleOrderItem;

import java.util.List;

/**
 * 标题:IUocInspOrderModel
 * 说明:验收单
 * 时间:2022/2/25 11:34
 * 作者:罗有
 */

public interface IUocInspOrderModel {
    /**
     * 创建验收单
     */
    void createInspOrder(UocInspOrderDo uocInspOrderDo);

    /**
     * 查询验收单主体
     *
     * @param uocInspOrderQryBo
     * @return
     */
    UocInspOrderDo getInspOrderMain(UocInspOrderQryBo uocInspOrderQryBo);

    /**
     * 查询验收单明细列表
     *
     * @param uocInspOrderItemQryBo
     * @return
     */
    UocInspOrderDo getListInspOrderItem(UocInspOrderItemQryBo uocInspOrderItemQryBo);

    /**
     * 查询验收单明细列表
     * @param uocInspOrderItemQryBo
     * @return
     */
    UocInspOrderDo getInspOrderItemList(UocInspOrderItemQryBo uocInspOrderItemQryBo);

    /**
     * 查询验收单列表
     *
     * @param uocInspOrderQryBo
     * @return
     */
    List<UocInspOrderDo> getListInspOrder(UocInspOrderQryBo uocInspOrderQryBo);
    /**
     * 获取验收单编号
     */
    UocInspOrderDo getInspOrderNo(UocInspOrderDo uocInspOrderDo);

    /**
     * 查询验收总金额总数量
     * @author wenle
     * @date 2022-04-02 10:06:02
     * @param uocInspOrderQryBo 入参
     * @return com.tydic.dyc.oc.model.insporder.UocInspOrderDo
     */
    UocInspOrderDo qryTotalFeeAndCount(UocInspOrderQryBo uocInspOrderQryBo);


    /***
     *修改明细在途数量
     * @param uocSaleOrderItem
     */
    void modifySaleOrderItemReturningCount(UocInspOrderItem uocSaleOrderItem);

    void modifyInspOrderItemChngingCount(UocInspOrderDo convertInspOrderDo);

    void modifyItemChngCountRefuse(UocInspOrderDo convertInspOrderDo);

    void modifyItemChngCountConfirm(UocInspOrderDo convertInspOrderDo);

    void modifyBatchItemInspConfirm(UocInspOrderDo convertInspOrderDo);

    void modifyItemChngCountConfirmAdd(UocInspOrderDo convertInspOrderDo);

    void modifyItemChngCountConfirmReduce(UocInspOrderDo convertInspOrderDo);

    void modifyInsporderChngTotalFeeConfirm(UocInspOrderDo convertInspOrderDo);
}
